@@ -108,11 +108,9 @@ class DB:
   Method to insert [dict] multiple data into the database.
   Data inserted as a list and ids are returned (print).
   """
-  def insertMany(self, data: dict):
-    lst = []
-    lst.append(data.copy())
+  def insertMany(self, data: list):
     mycol = DB.__createCol(self)
-    x = mycol.insert_many(lst)
+    x = mycol.insert_many(data)
     return f"Inserted datas with ids: {x.inserted_ids}"
   
   """
@@ -126,14 +124,14 @@ class DB:
 
   """
   Method to find all occurences in a collection in a database.
-  Data is returned as a [dict] dictionary with the _id field.
+  Data is returned as a [list] dictionary with the _id field.
   """
   def findAll(self):
     mycol = DB.__createCol(self)
     lst = []
     for data in mycol.find():
       lst.append(data)
-    return dict(lst)
+    return lst
 
   """
   Method to filter occurences in a collection in a database.
